AsyncStateError<T> class

Represents the error state.

An asynchronous cell is in this state when the Future held in it completes with an error.

Inheritance

Constructors

AsyncStateError(Object error, [StackTrace? trace, T? lastValue])
Create an AsyncState representing the error state with error.

Properties

error → Object
The error thrown while computing the asynchronous value
final
hashCode → int
The hash code for this object.
no setteroverride
isData → bool
Is this a data state?
no setterinherited
isError → bool
Is this an error state?
no setteroverride
isLoading → bool
Is this a pending asynchronous value state?
no setterinherited
lastValue → T?
The last value to which the Future completed or null if none.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace
The stacktrace of the exception that was thrown
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override