CellObserverModel class abstract

Provides the watch method for observing changes in cell.

Usage:

  1. Create a subclass
  2. Call watch in your methods to observe changes to cells
  3. Call dispose once the model is no longer used

Constructors

CellObserverModel()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Stop calling all watch functions registered with watch
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
watch(void fn()) → CellWatcher
Register a cell watch function fn.

Operators

operator ==(Object other) → bool
The equality operator.
inherited