CellWatcher class abstract

Maintains the state of a cell watcher.

A cell watcher is a function which is called whenever the values of the cells referenced within it change.

Implementers

Constructors

CellWatcher({dynamic key})
Create a CellWatcher identified by key.

Properties

callback → WatchCallback
The watch callback function
no setter
hashCode → int
The hash code for this object.
no setteroverride
isInitialized → bool
Has the watch function been called once to initialize its dependencies.
no setter
key ↔ dynamic
Key identifying watch function
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

afterInit() → void
Exit the watch function on the first call.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → void
Start the cell watcher
stop() → void
Stop watching the referenced cells.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

stopByKey(dynamic key) → void
Stop the watch function identified by key.