MetaCell<T> constructor

MetaCell<T>({
  1. dynamic key,
  2. ValueCell<T>? initial,
})

Create a cell that points to another cell.

The created cell is identified by key if it is non-null.

The cell initially points to initial if it is not null.

Implementation

MetaCell({
  super.key,
  this.initial
});