mutable<T> static method

MutableMetaCell<T> mutable<T>({
  1. dynamic key,
  2. MutableCell<T>? initial,
})

Create a MetaCell that points to a MutableCell.

The created cell is identified by key if it is non-null.

The cell initially points to initial if it is not null.

Implementation

static MutableMetaCell<T> mutable<T>({
  key,
  MutableCell<T>? initial
}) => MutableMetaCell(
    key: key,
    initial: initial
);