peek property
ValueCell<T>
get
peek
Use the value of this without reacting to changes.
This property returns a cell, which has the same value as this but does
not inform its observers when the value of this changes.
This should be used rather than accessing value directly or omitting
this as a dependency to ensure that this cell is kept active.
Implementation
ValueCell<T> get peek => PeekCell(this);