ValueCellExtension<T> extension

Adds the cell property for creating a constant cell.

on
  • T

Properties

cell → ValueCell<T>

Available on T, provided by the ValueCellExtension extension

Create a constant cell with value equal to this.
no setter
mutableCell → MutableCell<T>

Available on T, provided by the ValueCellExtension extension

Create a MutableCell with value initialized to this.
no setter