Watch class

A cell watch function which receives the watch state as an argument.

Inheritance

Constructors

Watch(WatchStateCallback watch, {dynamic key})
Register watch to be called whenever the values of the cells referenced within it change.

Properties

callback → WatchCallback
The watch callback function
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
isInitialized → bool
Has the watch function been called once to initialize its dependencies.
no setterinherited
key ↔ dynamic
Key identifying watch function
latefinalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
watch → WatchStateCallback
The watch callback function
final

Methods

afterInit() → void
Exit the watch function on the first call.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → void
Start the cell watcher
inherited
stop() → void
Stop watching the referenced cells.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited