CellKey5<T1, T2, T3, T4, T5> class

A key which is distinguished from other keys by five values.

Constructors

CellKey5(T1 value1, T2 value2, T3 value3, T4 value4, T5 value5)

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value1 → T1
The 1st value distinguishing the key from other keys of the same type.
final
value2 → T2
The 2nd value distinguishing the key from other keys of the same type.
final
value3 → T3
The 3rd value distinguishing the key from other keys of the same type.
final
value4 → T4
The 4th value distinguishing the key from other keys of the same type.
final
value5 → T5
The 5th value distinguishing the key from other keys of the same type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override