CellObserver class abstract

Interface for observing changes to the value of a ValueCell

Implementers

Constructors

CellObserver()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldNotifyAlways → bool
Should the observer be notified if the new value of the cell is equal to the previous value?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(ValueCell cell, bool didChange) → void
The observed cell has changed its value.
willUpdate(ValueCell cell) → void
The observed cell will change its value.

Operators

operator ==(Object other) → bool
The equality operator.
inherited