CellUpdateManager class

Provides functionality for managing the cell value update cycle

Constructors

CellUpdateManager()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

isUpdating → bool
Is a cell update cycle currently in progress
no setter

Static Methods

addPostUpdateCallback(PostUpdateCallback callback) → void
Schedule a callback to run after the current update cycle.
beginCellUpdates() → bool
Begin a cell update cycle, if one is not in progress already.
endCellUpdates(bool wasUpdating) → void
End a cell update cycle.