action static method
Create a MetaCell that points to an ActionCell.
The created cell is identified by key if it is non-null.
The cell initially points to initial if it is not null.
Implementation
static ActionMetaCell action({
key,
ActionCell? initial
}) => ActionMetaCell(
key: key,
initial: initial
);